import{ak as a}from"./index.bc940e3a.js";const n=a("tab",{state:()=>({tabData:"test1"}),getters:{tabDataGet(t){return t.tabData}},actions:{tabDataChange(t){this.tabData=t}},persist:{enable:!0}}),o=a("menu",{state:()=>({menuData:{tab:"test1",title:"",icon:"home",link:"/",routerTo:"/"},homeData:{tab:"test1",title:"",icon:"home",link:"/",routerTo:"/"}}),getters:{menuDataGet(t){return t.menuData},homePageGet(t){return t.homeData}},actions:{menuDataChange(t){this.menuData=t},homePage(t){this.homeData=t}},persist:{enable:!0}});export{o as a,n as u};
